library(pavo)
library(vegan) 
# install_github("pmartinezarbizu/pairwiseAdonis/pairwiseAdonis")
library(pairwiseAdonis)
library(ggplot2)
library(viridis)
library(heplots)

# 1) SET DATA ----
## Flower colors data ----
flower_colors <- read.csv("FlowerSpectra.csv", header=TRUE)
colnames(flower_colors) <- c('wl', 'fGp', 'fJi', 'fJo', 'fJr', 'fLj', 'fMj','fMl','fMp',
                              'fNl', 'fPa', 'fSc', 'fTx', 'fCp', 'fEg', 'fOa', 'fOp')
flower_colors <- as.rspec(flower_colors, lim = c(300, 700)) #make into reflectance spectra object, from 300 to 700nm
flower_colors <- procspec(flower_colors, fixneg = "zero") #remove any negative values and replace with zeroes
flower_colors <- flower_colors[,c(1:6,8:9,7,10:17)] #order alphabetically, first white flowers and then yellow flowers
head(flower_colors)

## Leaves colors data ----
leaves <- read.csv("LeavesSpectra.csv", header = T)
leaves <- as.rspec(leaves, lim = c(300, 700)) #make into reflectance spectra object, from 300 to 700nm
leaves <- procspec(leaves, fixneg = "zero") #remove any negative values and replace with zeroes
head(leaves)

## average leaves
avg.leaves <- data.frame(wl = leaves[,1], leaves = rowMeans(leaves[,-1])) 
avg.leaves<-procspec(avg.leaves, fixneg = "zero") #remove any negative values and replace with zeroes
head(avg.leaves)

flowers_avgleaves <- cbind(flower_colors, hProm = avg.leaves[,c(-1)]) #flowers+average leaves
flowers_avgleaves <- as.rspec(flowers_avgleaves, lim = c(300, 700)) #make into reflectance spectra object, from 300 to 700nm
head(flowers_avgleaves)
part <- substr(colnames(flowers_avgleaves[-1]), start=1, stop=1) # classifies flowers (f) and average leaves (h)
as.matrix(part)
part <- as.factor(part)
part

### not average leaves
flowers_leaves <- cbind(flower_colors, leaves[,-1]) #flowers+not average leaves
head(flowers_leaves)
flowers_leaves <- as.rspec(flowers_leaves, lim = c(300, 700))#make into reflectance spectra object, from 300 to 700nm
flowers_leaves <- procspec(flowers_leaves, fixneg = "zero")#remove any negative values and replace with zeroes
head(flowers_leaves)
part2 <- substr(colnames(flowers_leaves[-1]), start=1, stop=1) # classifies flowers and leaves
as.matrix(part2)
part2 <- as.factor(part2)
part2
head(flowers_leaves)

## Natural backgrounds data ----
natural_backgrounds <- read.csv('BkgSpectra.csv')
natural_backgrounds <- as.rspec(natural_backgrounds, lim = c(300, 700)) #make into reflectance spectra object, from 300 to 700nm
natural_backgrounds <- procspec(natural_backgrounds, fixneg = "zero") #remove any negative values and replace with zeroes
sand <- natural_backgrounds$sustrato.arena #sand background
soil <- natural_backgrounds$sustrato.tierra #soil background
gravel <- natural_backgrounds$sustrato.roca #gravel background
green <- avg.leaves$leaves
natural_backgrounds$green <- green
head(natural_backgrounds)

## Light data ----
luces <- read.csv("LightSpectra.csv", header=TRUE)#contains wavelengths in col1, then 24 light types
luces <- as.rspec(luces,lim=c(300,700))#make into reflectance spectra object, from 300 to 700nm
luces <-procspec(luces, fixneg = 'zero') #remove any negative values and replace with zeroes
LIGHTNAMES<-c(colnames(luces)[2:8], "Twilight_-10.8deg", colnames(luces)[10:25])#define lightnames vector

#threshold lights: set any value below 1/100th max radiance to 1*10^(-16)
#values equal to 0 are not altered, as they indicate an absence of measurement for that wavelength
thresh_light <- rep(0,(length(colnames(luces))-1))
luces_umbral <- luces
for (i in 1:length(LIGHTNAMES)){
  thresh_light[i]<-max(luces[,i+1])/100 # a partir de la columna 2, toma el valor maximo de cada tipo de luz y lo divide en 100
  for(j in 1:length(luces$wl)){
    if (luces[j,i+1]< thresh_light[i]&luces[j,i+1]!=0){
      luces_umbral[j,i+1]<-1*10^(-16)
    }
  }
}
head(luces_umbral)
#core light set - D65, full moon and artificial lights
luces_key_umbral <- cbind(luces_umbral[,1:3],luces_umbral[,12:25])
head(luces_key_umbral)
luces_key <- c(LIGHTNAMES[1:2],LIGHTNAMES[11:24])
## vectorized lights
luz_mv <- luces_key_umbral$MV #mercury vapor
luz_hps <- luces_key_umbral$HPS #high pressure sodium
luz_led5000 <- luces_key_umbral$LED_5000K
luz_lunallena <- luces_key_umbral$Moon_full
luz_tw1 <- luces_umbral$Twilight_1deg # twilight
luz_st1 <- luces_umbral$Starlight1 # starlight (max)

## Manduca sexta data ----
m.sexta <- sensmodel(peaksens = c(357, 450, 520)) #M. sexta peak photoreceptor sensitivity

# 2) PLOTS REFLECTANCE SPECTRA ----
## Reflectance spectra flowers ----
layout(1)
flower_colors <- as.rspec(flower_colors, lim = c(300, 700)) #make into reflectance spectra object, from 300 to 700nm
flower_colors <- procspec(flower_colors, fixneg = "zero") #remove any negative values and replace with zeroes
head(flower_colors)

#plot parameters
f_col <- c('#4E79A7FF', '#BAB0ACFF', '#B07AA1FF', 
           '#D4A6C8FF', '#F1CE63FF', '#D7B5A6FF',
           '#E15759FF', '#F28E2BFF', '#59A14FFF',
           '#A0CBE8FF', '#499894FF', '#FF9D9AFF', '#8CD17DFF',
           '#B6992DFF',  '#79706EFF', '#9D7660FF') # species colors
sp <-c("G. platensis", "J. integrifolia", "J. odonelliana", 
       "J. runcinata", "L. japonica" , "M. jalapa", 
       "M. laxa", "M. petraea", "N. longiflora" , "P. axillaris", 
       "S. candicans", "T. xiphiodes", "C. parqui" , 
       "E. gilliesii" ,  "O. affinis", 'O. picensis') # species names

plot(flower_colors, col = f_col, ylim=c(0,100), lwd=2 ,type = 'overlay')
legend("topleft", legend=sp, fill=f_col, cex =0.5)
head(flower_colors)

## Reflectance spectra leaves ----
head(leaves)
leaves <- as.rspec(leaves, lim = c(300, 700)) #make into reflectance spectra object, from 300 to 700nm
leaves <- procspec(leaves, opt="smooth", fixneg = "zero") #remove any negative values and replace with zeroes

#plot parameters               
col_hojas <- c('#4E79A7FF', '#BAB0ACFF', '#B07AA1FF', '#D4A6C8FF', 
               '#F1CE63FF', '#D7B5A6FF', '#E15759FF', '#F28E2BFF', 
               '#59A14FFF', '#A0CBE8FF', '#499894FF', '#FF9D9AFF', 
               '#8CD17DFF', '#B6992DFF',  '#79706EFF', '#9D7660FF') # species colors
               
plot(leaves, col= col_hojas, ylim=c(0,100), lwd=2 , type = 'overlay')
legend("topleft", legend=sp, fill = col_hojas, cex =0.5)

## Reflectance spectra backgrounds ----
head(natural_backgrounds)
#plot parameters
col_bkg <- c("#8B4513", "#F4A460", 
             "#A9A9A9","#458B00") # background colors
plot(natural_backgrounds, col= col_bkg, 
                                lwd=2, ylim=c(0,80))
legend('topleft', legend=c('Soil', 'Sand','Gravel','Green background'),
       lty=1,  col = col_bkg, lwd = 2)

## Reflectance spectra lights ----
#normalise to max=1 for plotting purposes and then to percentage:
LIGHTS_PLOT<-luces
for(i in 2:25){
  LIGHTS_PLOT[,i]<-luces[,i]/max(luces[,i])*100
}
luces_plot <- data.frame(LIGHTS_PLOT[,c(1:2,8,10,18:20)])
luces_plot <- as.rspec(luces_plot,lim=c(300,700))
table_luces <- data.frame(luces_key_umbral$wl,
                          luces_key_umbral$MV,
                          luces_key_umbral$HPS,
                          luces_key_umbral$LED_5000K,
                          luces_key_umbral$Moon_full,
                          luces_umbral$Twilight_1deg,
                          luces_umbral$Starlight1)
table_luces <- as.rspec(table_luces, lim = c(300, 700)) #make into reflectance spectra object, from 300 to 700nm
table_luces <- procspec(table_luces, fixneg = "zero") #remove any negative values and replace with zeroes

#plot parameters
col_lights <- c("#440154FF","#414487FF","#2A788EFF",
                "#22A884FF","#7AD151FF","#FDE725FF") # light colors

plot(luces_plot, col= col_lights, lwd=2)
legend('topleft', legend=colnames(luces_plot[,-1]), 
       lty=1, col = col_lights, lwd = 2, cex = 0.5)

# 3) VISUAL MODEL ----
head(flowers_leaves)
# plot parameters
f_l_col <- c(rep('white', 12), # 12 white flowers
             rep('#F1CE63FF', 4), # 4 yellow flowers
             rep('#59A14FFF', 16)) # 16 leaves

# vismodel() calculate quantum catches for each photoreceptor type 
# considering different illumination (x) and different background (y).
# Quantum caches were used to place color loci in a Maxwell triangle by colspace().
colsp <- function (x,y) {
         vs <- vismodel(flowers_leaves, visual = m.sexta, qcatch = "Qi", achromatic = "l", 
                        illum = x, relative = F, bkg = y, vonkries = T) 
         cp <- colspace(vs, space = "tri")
         plot(cp, pch = 21, bg=f_l_col, col = 'black', cex=1.15, lwd=0.5)
}

### Visual model green background
par(mfrow=c(2,3))
colsp(luz_lunallena, green); title(main = "Full moon\nbkg green")
colsp(luz_tw1, green); title(main = "Twilight\nbkg green")
colsp(luz_st1, green); title(main = "Starlight\nbkg green")
colsp(luz_led5000, green); title(main = "LED\nbkg green")
colsp(luz_mv, green); title(main = "MV\nbkg green")
colsp(luz_hps, green); title(main = "HPS\nbkg green")
                    
### Visual model sand background
par(mfrow=c(2,3))
colsp(luz_lunallena, sand); title(main = "Full moon\nsand")
colsp(luz_tw1, sand); title(main = "Twilight\nsand")
colsp(luz_st1, sand); title(main = "Starlight\nsand")
colsp(luz_led5000, sand); title(main = "LED\nsand")
colsp(luz_mv, sand); title(main = "MV\nsand")
colsp(luz_hps, sand); title(main = "HPS\nsand")
layout(1)

### Visual model soil background
par(mfrow=c(2,3))
colsp(luz_lunallena, soil); title(main = "Full moon\nsoil")
colsp(luz_tw1, soil); title(main = "Twilight\nsoil")
colsp(luz_st1, soil); title(main = "Starlight\nsoil")
colsp(luz_led5000, soil); title(main = "LED\nsoil")
colsp(luz_mv, soil); title(main = "MV\nsoil")
colsp(luz_hps, soil); title(main = "HPS\nsoil")
layout(1)

### Visual model gravel background
par(mfrow=c(2,3))
colsp(luz_lunallena, gravel); title(main = "Full moon\ngravel")
colsp(luz_tw1, gravel); title(main = "Twilight\ngravel")
colsp(luz_st1, gravel); title(main = "Starlight\ngravel")
colsp(luz_led5000, gravel); title(main = "LED\ngravel")
colsp(luz_mv, gravel); title(main = "MV\ngravel")
colsp(luz_hps, gravel); title(main = "HPS\ngravel")
layout(1)

# 4) PERMANOVA  ----
test <- function(y,z){
  vs <- vismodel(flowers_leaves, visual = m.sexta, qcatch = "Qi", achromatic = "l", 
                 illum = y, relative = F, bkg = z, vonkries = T) # vismodel using reflectance spectra of flowers or leaves (x) 
                                                                 # for each illumination (y) and background (z)
  colnames(vs) <- c("u", "s", "m","lum")
  cdist <- coldist(vs, n = c(0.1, 0.23, 0.67), noise='neural', 
                   weber = 0.1, weber.achro = 0.16, achro = F) 
  head(cdist)
  jnd <- jnd2xyz(cdist, ref1 = "m") # converts coldist result into Cartesian coordinates that are perceptually-corrected
  group <- substring(rownames(as.matrix(jnd)), 1, 1) # set flowers and leaves as groups
  bdisp <- betadisper(dist(jnd), group, type='centroid') # distance-based test of homogeneity of within-group dispersions 
  an <- anova(bdisp) 
  pmanova <- adonis2(jnd~group, method="euclidean", permutations = 10000)
  tests <- list(an, pmanova)
  tests
}
# plots
spider <- function(y, z){
  vs <- vismodel(flowers_leaves, visual = m.sexta, qcatch = "Qi", achromatic = "l", 
                 illum = y, relative = F, bkg = z, vonkries = T)
  colnames(vs) <- c("u", "s", "m","lum")
  cdist <- coldist(vs, n = c(0.1, 0.23, 0.67), noise='neural', 
                   weber = 0.1, weber.achro = 0.16, achro = F)
  jnd <- jnd2xyz(cdist, ref1 = 'm')
  plot(as.data.frame(jnd))
  #plot parameters
  rect(par("usr")[1], par("usr")[3],
       par("usr")[2], par("usr")[4],
       col = "#e6e6e6ff")
  points(as.data.frame(jnd), col=c(rep("black",16), #16 flowers
                                   rep("#10a53dFF",16)), #16 leaves
         cex=1.5, pch=21, bg=c(rep("black",16), #16 flowers
                               rep("#10a53dFF",16))) #16 leaves
  with(jnd, ordispider(jnd, groups = substring(rownames(as.matrix(jnd)), 1, 1),
                      label = F, col = c("black","#10a53dFF")))
  # text(jnd$x, jnd$y,labels = c(1:16, 1:16), col=c(rep("black",32)),
       # pos = 3, cex = 1)
}

### Green background ----
test_green <- list('Full moon' = test(luz_lunallena, green),
                   'Twilight' = test(luz_tw1, green),
                   'Starlight'  = test(luz_st1, green),
                   'LED' = test(luz_led5000, green),
                   'Mercury vapor' = test(luz_mv, green), 
                   'HPS' = test(luz_hps, green))
test_green

# references for legend
# sp_fl <-c("1) G. platensis (flower)", "2) J. integrifolia (flower)",
#           "3) J. odonelliana (flower)","4) J. runcinata (flower)",
#           "5) L. japonica (flower)" ,"6) M. laxa (flower)",
#           "7) M. petraea (flower)", "8) M. jalapa (flower)",
#           "9) N. longiflora (flower)" ,"10) P. axillaris (flower)",
#           "11) S. candicans (flower)","12) T. xiphiodes (flower)",
#           "13) C. parqui (flower)" ,"14) E. gilliesii (flower)"
#           ,"15) O. affinis (flower)", '16) O. picensis (flower)',
#           "17) G. platensis (leaf)","18) J. integrifolia (leaf)",
#           "19) J. odonelliana (leaf)", '20) J. runcinata (leaf)',
#           "21) L. japonica (leaf)","22) M. laxa (leaf)",
#           "23) M. petraea (leaf)", "24) M. jalapa (leaf)",
#           "25) N. longiflora (leaf)", "26) P. axillaris (leaf)",
#           "27) S. candicans (leaf)","28) T. xiphiodes (leaf)",
#           "29) C. parqui (leaf)", "30) E. gilliesii (leaf)",
#           "31) O. affinis (leaf)", "32) O. picensis (leaf)") # species names and parts

par(mfrow=c(2,3))
spider(luz_lunallena, green); title(main = "Full moon (*)")
spider(luz_tw1, green); title(main = "Twilight (*)")
spider(luz_st1, green); title(main = "Starlight (**)")
spider(luz_led5000, green); title(main = "Light-emitting diode\n(5000 K)")
spider(luz_mv, green); title(main = "Mercury vapor (*)")
spider(luz_hps, green); title(main = "High-pressure sodium")
# legend("bottom",
#        legend=sp_fl, fill = c(rep("white",12), rep("#ffcf20FF",4),
#                               rep("#10a53dFF",8)), cex=0.9, ncol = 3)
layout(1)

### Gravel background ----
test_gravel <- list('Full moon' = test(luz_lunallena, gravel),
                  'Twilight' = test(luz_tw1, gravel),
                  'Starlight'  = test(luz_st1, gravel),
                  'LED' = test(luz_led5000, gravel),
                  'Mercury vapor' = test(luz_mv, gravel), 
                  'HPS' = test(luz_hps, gravel))
test_gravel

par(mfrow=c(2,3))
spider(luz_lunallena, gravel); title(main = "Full moon (*)")
spider(luz_tw1, gravel); title(main = "Twilight (*)")
spider(luz_st1, gravel); title(main = "Starlight (*)")
spider(luz_led5000, gravel); title(main = "Light-emitting diode\n(5000 K)")
spider(luz_mv, gravel); title(main = "Mercury vapor (*)")
spider(luz_hps, gravel); title(main = "High-pressure sodium")
layout(1)

### Sand background ----
test_sand <- list('Full moon' = test(luz_lunallena, sand),
                  'Twilight' = test(luz_tw1, sand),
                  'Starlight'  = test(luz_st1, sand),
                  'LED' = test(luz_led5000, sand),
                  'Mercury vapor' = test(luz_mv, sand), 
                  'HPS' = test(luz_hps, sand))
test_sand

par(mfrow=c(2,3))
spider(luz_lunallena, sand); title(main = "Full moon (*)")
spider(luz_tw1, sand); title(main = "Twilight (*)")
spider(luz_st1, sand); title(main = "Starlight (**)")
spider(luz_led5000, sand); title(main = "Light-emitting diode\n(5000 K)")
spider(luz_mv, sand); title(main = "Mercury vapor (*)")
spider(luz_hps, sand); title(main = "High-pressure sodium")
layout(1)

### Soil background ----
test_soil <- list('Full moon' = test(luz_lunallena, soil),
                  'Twilight' = test(luz_tw1, soil),
                  'Starlight'  = test(luz_st1, soil),
                  'LED' = test(luz_led5000, soil),
                  'Mercury vapor' = test(luz_mv, soil), 
                  'HPS' = test(luz_hps, soil))
test_soil

par(mfrow=c(2,3))
spider(luz_lunallena, soil); title(main = "Full moon (*)")
spider(luz_tw1, soil); title(main = "Twilight (*)")
spider(luz_st1, soil); title(main = "Starlight (*)")
spider(luz_led5000, soil); title(main = "Light-emitting diode\n(5000 K)")
spider(luz_mv, soil); title(main = "Mercury vapor (*)")
spider(luz_hps, soil); title(main = "High-pressure sodium")
layout(1)

# 5) JND flowers vs leaves ----
head(flower_colors)
colnames(flower_colors) <- c('wl', 'wfGp', 'wfJi', 'wfJo', 'wfJr', 'wfLj', 
                              'wfMl','wfMp','wfMj','wfNl', 'wfPa', 'wfSc', 'wfTx',
                              'yfCp', 'yfEg', 'yfOa', 'yfOp') #wf to white flowers & yf to yellow flowers
head(leaves)
colnames(leaves) <- c('wl', 'whGp', 'whJi', 'whJo', 'whJr', 'whLj', 
                             'whMl','whMp','whMj','whNl', 'whPa', 'whSc', 'whTx',
                             'yhCp', 'yhEg', 'yhOa', 'yhOp') #wh to leaves of species with white flowers & yh to leaves of species with yellow flowers
fh_wy <- cbind(flower_colors, leaves[,-1])
head(fh_wy)
species1 <- substring(colnames(fh_wy[-1]), 3, 4)
species_names <- species1[1:(length(species1)/2)]; species_names

# chromatic contrast ----
jnd.fh <- function(i,j,k,m) {
            vis <- vismodel(fh_wy, visual = m.sexta, qcatch = "Qi", achromatic = "l", 
                            illum = i, relative = F, bkg = j, vonkries = T)
            colnames(vis) <- c("u", "s", "m","lum")
            part <- as.factor(c('f', 'h')) # two factor levels to compare flower vs leaf of the same species
            # for-loop
            boot <- NULL #empty object to fill
            for (i in species_names) {
              vs.sp <- as.data.frame(subset(vis, 
                                            subset = substring(rownames(vis), 3, 4) == i))
              boot.sp <- as.data.frame(bootcoldist(vs.sp, by = part, 
                                                   n = c(0.1, 0.23, 0.67), 
                                                   weber = 0.1, weber.achro = 0.16, 
                                                   achromatic = F)) 
              boot <- rbind(boot, boot.sp)
            }
            boot
            #calculate mean, standard deviation, standard error and confidence interval 
            # of the JND flower vs. leaves for each species
            # for-loop
            rn <- NULL #empty object to fill
            sp <- NULL #empty object to fill
            for (s in species_names) {
              rn <- paste('f-h', s, sep = '')
              sp <- c(sp,rn)
            }
            sp
            mean.ds <- mean(boot$dS.mean) 
            sd <- sd(boot$dS.mean)
            se <- sd/sqrt(nrow(boot))
            ic.up <- mean.ds+(1.96*se)
            ic.lw <- mean.ds-(1.96*se)
            # organize the information to plot
            jnd <- data.frame("dS.mean" = mean.ds, "dS.lwr" = ic.lw, "dS.upr" = ic.up)
            jnd$sp <- NA
            jnd$luz <- k
            boot$sp <- species_names
            boot$luz <- c(rep(k, nrow(boot)))
            gplot <- rbind(jnd, boot)
            rownames(gplot) <- c('resumen', sp)
            gplot
            gplot$bkg <- rep(m, nrow(gplot))
            gplot
}

# Green background
jnd.fh.fm.green <- jnd.fh(luz_lunallena, green, 'Full moon', 'a) Green background')
jnd.fh.st.green <- jnd.fh(luz_st1, green, 'Starlight', 'a) Green background')
jnd.fh.tw.green <- jnd.fh(luz_tw1, green, 'Twilight', 'a) Green background')
jnd.fh.led.green <- jnd.fh(luz_led5000, green, 'LED', 'a) Green background')
jnd.fh.mv.green <- jnd.fh(luz_mv, green, 'MV', 'a) Green background')
jnd.fh.hps.green <- jnd.fh(luz_hps, green, 'HPS', 'a) Green background')

jnd.fh.green <- rbind(jnd.fh.fm.green, jnd.fh.st.green, jnd.fh.tw.green,
                      jnd.fh.led.green, jnd.fh.mv.green, jnd.fh.hps.green)
jnd.fh.green$parts <- rep('f-h', nrow(jnd.fh.green))
jnd.fh.green$luz <- factor(jnd.fh.green$luz,
                             levels = c('Full moon', 'Twilight', 'Starlight',
                                        'LED', 'MV', 'HPS'))
jnd.fh.green$cod <- rep(c(1, rep(2, 16)), 6)
jnd.fh.green$col <- rep(c(NA, rep('b',12), rep('a', 4)), 6)
head(jnd.fh.green)

# plot green background
ggplot(jnd.fh.green) +
  geom_pointrange(aes(jnd.fh.green[,8], #code to plot in two columns
                      jnd.fh.green[,1], #dS.mean
                      ymin=jnd.fh.green[,2], #dS.lwr
                      ymax=jnd.fh.green[,3]), col='black') + #dS.upr 
  geom_point(aes(x = jnd.fh.green[,8], #code to plot in two columns
                 y= jnd.fh.green[,1], #dS.mean
                 col = jnd.fh.green[,9])) + #col to indicate if it is yellow or white 
  geom_text(aes(x = jnd.fh.green[,8], #code to plot in two columns
                y= jnd.fh.green[,1]), #dS.mean
            label = rep(c(0:16),6), 
            size = 2.7, hjust = 2) +
  facet_grid(cod~luz) +
  scale_y_continuous(expand = c(0,0), limit = c(-1,10.8), 
                     breaks = seq(-1, 10.8, by = 2)) +
  geom_hline(aes(yintercept=1), linetype=2)  +
  labs(x = "Flowers - Leaves", y = "Chromatic contrast (Delta-S)", 
       col = 'Light') +
  theme_bw() + 
  theme(axis.text.x = element_blank(), 
        axis.ticks = element_blank(),
        panel.grid.major.y = element_line(color="gray87"),
        panel.grid.minor.y = element_blank(),
        panel.grid.major.x = element_blank(),
        panel.grid.minor.x = element_blank(),
        legend.text = element_blank(),
        legend.position='none')

### other backgrounds ----
# Gravel background
jnd.fh.fm.gravel <- jnd.fh(luz_lunallena, gravel, 'Full moon', 'b) Gravel background')
jnd.fh.st.gravel <- jnd.fh(luz_st1, gravel, 'Starlight', 'b) Gravel background')
jnd.fh.tw.gravel <- jnd.fh(luz_tw1, gravel, 'Twilight', 'b) Gravel background')
jnd.fh.hps.gravel <- jnd.fh(luz_hps, gravel, 'HPS', 'b) Gravel background')
jnd.fh.led.gravel <- jnd.fh(luz_led5000, gravel, 'LED', 'b) Gravel background')
jnd.fh.mv.gravel <- jnd.fh(luz_mv, gravel, 'MV', 'b) Gravel background')

jnd.fh.gravel <- rbind(jnd.fh.fm.gravel, jnd.fh.st.gravel, jnd.fh.tw.gravel,
                       jnd.fh.led.gravel, jnd.fh.mv.gravel, jnd.fh.hps.gravel)
head(jnd.fh.gravel)
jnd.fh.gravel$luz <- factor(jnd.fh.gravel$luz,
                             levels = c('Full moon', 'Twilight', 'Starlight',
                                        'LED', 'MV', 'HPS'))
jnd.fh.gravel$parts <- rep('f-h', nrow(jnd.fh.gravel))
jnd.fh.gravel$cod <- rep(c(1, rep(2, 16)), 6)
jnd.fh.gravel$col <- rep(c(NA, rep('b',12), rep('a', 4)), 6)
head(jnd.fh.gravel)

# plot gravel background
ggplot(jnd.fh.gravel) +
  geom_pointrange(aes(jnd.fh.gravel[,8], #code to plot in two columns
                      jnd.fh.gravel[,1], #dS.mean
                      ymin=jnd.fh.gravel[,2], #dS.lwr
                      ymax=jnd.fh.gravel[,3])) + #dS.upr 
  geom_point(aes(x = jnd.fh.gravel[,8], #code to plot in two columns
                 y= jnd.fh.gravel[,1], #dS.mean
                 col = jnd.fh.gravel[,9])) + #col to indicate if it is yellow or white
  geom_text(aes(x = jnd.fh.gravel[,8], #code to plot in two columns
                y= jnd.fh.gravel[,1]), #dS.mean
            label = rep(c(0:16),6), 
            size = 2.7, hjust = 2) +
  facet_grid(cod~luz) +
  scale_y_continuous(expand = c(0,0), limit = c(-1,10.8), 
                     breaks = seq(-1, 10.8, by = 2)) +
  geom_hline(aes(yintercept=1), linetype=2)  +
  labs(x = "Flowers - Leaves", y = "Chromatic contrast (Delta-S)", 
       col = 'Light') +
  theme_bw() + 
  theme(axis.text.x = element_blank(), 
        axis.ticks = element_blank(),
        panel.grid.major.y = element_line(color="gray87"),
        panel.grid.minor.y = element_blank(),
        panel.grid.major.x = element_blank(),
        panel.grid.minor.x = element_blank(),
        legend.position='none')

# Sand background
jnd.fh.fm.sand <- jnd.fh(luz_lunallena, sand, 'Full moon', 'c) Sand background')
jnd.fh.st.sand <- jnd.fh(luz_st1, sand, 'Starlight', 'c) Sand background')
jnd.fh.tw.sand <- jnd.fh(luz_tw1, sand, 'Twilight', 'c) Sand background')
jnd.fh.hps.sand <- jnd.fh(luz_hps, sand, 'HPS', 'c) Sand background')
jnd.fh.led.sand <- jnd.fh(luz_led5000, sand, 'LED', 'c) Sand background')
jnd.fh.mv.sand <- jnd.fh(luz_mv, sand, 'MV', 'c) Sand background')

jnd.fh.sand <- rbind(jnd.fh.fm.sand, jnd.fh.st.sand, jnd.fh.tw.sand,
                      jnd.fh.led.sand, jnd.fh.mv.sand, jnd.fh.hps.sand)
head(jnd.fh.sand)
jnd.fh.sand$luz <- factor(jnd.fh.sand$luz,
                            levels = c('Full moon', 'Twilight', 'Starlight',
                                       'LED', 'MV', 'HPS'))
jnd.fh.sand$parts <- rep('f-h', nrow(jnd.fh.sand))
jnd.fh.sand$cod <- rep(c(1, rep(2, 16)), 6)
jnd.fh.sand$col <- rep(c(NA, rep('b',12), rep('a', 4)), 6)
head(jnd.fh.sand)

# plot sand background
ggplot(jnd.fh.sand) +
  geom_pointrange(aes(jnd.fh.sand[,8], #code to plot in two columns
                      jnd.fh.sand[,1], #dS.mean
                      ymin=jnd.fh.sand[,2], #dS.lwr
                      ymax=jnd.fh.sand[,3])) + #dS.upr 
  geom_point(aes(x = jnd.fh.sand[,8], #code to plot in two columns
                 y= jnd.fh.sand[,1], #dS.mean
                 col = jnd.fh.sand[,9])) + #col to indicate if it is yellow or white
  geom_text(aes(x = jnd.fh.sand[,8], #code to plot in two columns
                y= jnd.fh.sand[,1]), #dS.mean
            label = rep(c(0:16),6), 
            size = 2.7, hjust = 2) +
  facet_grid(cod~luz) +
  scale_y_continuous(expand = c(0,0), limit = c(-1,10.8), 
                     breaks = seq(-1, 10.8, by = 2)) +
  geom_hline(aes(yintercept=1), linetype=2)  +
  labs(x = "Flowers - Leaves", y = "Chromatic contrast (Delta-S)", 
       col = 'Light') +
  theme_bw() + 
  theme(axis.text.x = element_blank(), 
        axis.ticks = element_blank(),
        panel.grid.major.y = element_line(color="gray87"),
        panel.grid.minor.y = element_blank(),
        panel.grid.major.x = element_blank(),
        panel.grid.minor.x = element_blank(),
        legend.position='none')  

# Soil background
jnd.fh.fm.soil <- jnd.fh(luz_lunallena, soil, 'Full moon', 'd) Soil background')
jnd.fh.st.soil <- jnd.fh(luz_st1, soil, 'Starlight', 'd) Soil background')
jnd.fh.tw.soil <- jnd.fh(luz_tw1, soil, 'Twilight', 'd) Soil background')
jnd.fh.hps.soil <- jnd.fh(luz_hps, soil, 'HPS', 'd) Soil background')
jnd.fh.led.soil <- jnd.fh(luz_led5000, soil, 'LED', 'd) Soil background')
jnd.fh.mv.soil <- jnd.fh(luz_mv, soil, 'MV', 'd) Soil background')

jnd.fh.soil <- rbind(jnd.fh.fm.soil, jnd.fh.st.soil, jnd.fh.tw.soil,
                    jnd.fh.led.soil, jnd.fh.mv.soil, jnd.fh.hps.soil)
head(jnd.fh.soil)
jnd.fh.soil$luz <- factor(jnd.fh.soil$luz,
                            levels = c('Full moon', 'Twilight', 'Starlight',
                                       'LED', 'MV', 'HPS'))
jnd.fh.soil$parts <- rep('f-h', nrow(jnd.fh.soil))
jnd.fh.soil$cod <- rep(c(1, rep(2, 16)), 6)
jnd.fh.soil$col <- rep(c(NA, rep('b',12), rep('a', 4)), 6)
head(jnd.fh.soil)

# plot soil background
ggplot(jnd.fh.soil) +
  geom_pointrange(aes(jnd.fh.soil[,8], #code to plot in two columns
                      jnd.fh.soil[,1], #dS.mean
                      ymin=jnd.fh.soil[,2], #dS.lwr
                      ymax=jnd.fh.soil[,3])) + #dS.upr 
  geom_point(aes(x = jnd.fh.soil[,8], #code to plot in two columns
                 y= jnd.fh.soil[,1], #dS.mean
                 col = jnd.fh.soil[,9])) + #col to indicate if it is yellow or white 
  geom_text(aes(x = jnd.fh.soil[,8], #code to plot in two columns
                y= jnd.fh.soil[,1]), #dS.mean
            label = rep(c(0:16),6), 
            size = 2.7, hjust = 2) +
  facet_grid(cod~luz) +
  scale_y_continuous(expand = c(0,0), limit = c(-1,10.8), 
                     breaks = seq(-1, 10.8, by = 2)) +
  geom_hline(aes(yintercept=1), linetype=2)  +
  labs(x = "Flowers - Leaves", y = "Chromatic contrast (Delta-S)", 
       col = 'Light') +
  theme_bw() + 
  theme(axis.text.x = element_blank(), 
        axis.ticks = element_blank(),
        panel.grid.major.y = element_line(color="gray87"),
        panel.grid.minor.y = element_blank(),
        panel.grid.major.x = element_blank(),
        panel.grid.minor.x = element_blank(),
        legend.position='none')  

# achromatic constrast ----
jnd.fh_achro <- function(i,j,k,m) {
                vis <- vismodel(fh_wy, visual = m.sexta, qcatch = "Qi", 
                                achromatic = "l", 
                                illum = i, relative = F, 
                                bkg = j, vonkries = T)
                colnames(vis) <- c("u", "s", "m","lum")
                part <- as.factor(c('f', 'h')) # two factor levels to compare flower vs leaf of the same species
                # for-loop
                boot <- NULL #empty object to fill
                for (i in species_names) {
                  vs.sp <- as.data.frame(subset(vis, subset = substring(rownames(vis), 3, 4) == i))
                  boot.sp <- as.data.frame(bootcoldist(vs.sp, by = part, 
                                                       n = c(0.1, 0.23, 0.67), 
                                                       weber = 0.1, 
                                                       weber.achro = 0.16, 
                                                       achromatic = T))  
                  boot <- rbind(boot, boot.sp)
                }
                boot
                #calculate mean, standard deviation, standard error and confidence interval 
                # of the JND flower vs. leaves for each species
                # for-loop
                rn <- NULL #empty object to fill
                sp <- NULL #empty object to fill
                for (s in species_names) {
                  rn <- paste('f-h', s, sep = '')
                  sp <- c(sp,rn)
                }
                sp
                mean.dl <- mean(boot$dL.mean) 
                sd <- sd(boot$dL.mean)
                se <- sd/sqrt(nrow(boot))
                ic.up <- mean.dl+(1.96*se)
                ic.lw <- mean.dl-(1.96*se)
                # organize the information to plot
                jnd <- data.frame("dL.mean" = mean.dl, "dL.lwr" = ic.lw, "dL.upr" = ic.up)
                jnd$sp <- NA
                jnd$luz <- k
                boot$sp <- species_names
                boot$luz <- c(rep(k, nrow(boot)))
                gplot <- rbind(jnd, boot[,c(4:8)])
                rownames(gplot) <- c('resumen', sp)
                gplot
                gplot$bkg <- rep(m, nrow(gplot))
                gplot
}

# Green background
jnd.fh.fm.green_achro <- jnd.fh_achro(luz_lunallena, green, 'Full moon', 'a) Green background')
jnd.fh.st.green_achro <- jnd.fh_achro(luz_st1, green, 'Starlight', 'a) Green background')
jnd.fh.tw.green_achro <- jnd.fh_achro(luz_tw1, green, 'Twilight', 'a) Green background')
jnd.fh.led.green_achro <- jnd.fh_achro(luz_led5000, green, 'LED', 'a) Green background')
jnd.fh.mv.green_achro <- jnd.fh_achro(luz_mv, green, 'MV', 'a) Green background')
jnd.fh.hps.green_achro <- jnd.fh_achro(luz_hps, green, 'HPS', 'a) Green background')

jnd.fh.green_achro <- rbind(jnd.fh.fm.green_achro, jnd.fh.st.green_achro, 
                            jnd.fh.tw.green_achro,jnd.fh.led.green_achro,
                            jnd.fh.mv.green_achro, jnd.fh.hps.green_achro)
jnd.fh.green_achro$parts <- rep('f-h', nrow(jnd.fh.green_achro))
jnd.fh.green_achro$luz <- factor(jnd.fh.green_achro$luz,
                           levels = c('Full moon', 'Twilight', 'Starlight',
                                      'LED', 'MV', 'HPS'))
jnd.fh.green_achro$cod <- rep(c(1, rep(2, 16)), 6)
jnd.fh.green_achro$col <- rep(c(NA, rep('b',12), rep('a', 4)), 6)
head(jnd.fh.green_achro)

# plot green background
ggplot(jnd.fh.green_achro) +
  geom_pointrange(aes(jnd.fh.green_achro[,8], #code to plot in two columns
                      jnd.fh.green_achro[,1], #dS.mean
                      ymin=jnd.fh.green_achro[,2], #dS.lwr
                      ymax=jnd.fh.green_achro[,3]), col='black') + #dS.upr 
  geom_point(aes(x = jnd.fh.green_achro[,8], #code to plot in two columns
                 y= jnd.fh.green_achro[,1], #dS.mean
                 col = jnd.fh.green_achro[,9])) + #col to indicate if it is yellow or white 
  geom_text(aes(x = jnd.fh.green_achro[,8], #code to plot in two columns
                y= jnd.fh.green_achro[,1]), #dS.mean
            label = rep(c(0:16),6), 
            size = 2.7, hjust = 2) +
  facet_grid(cod~luz) +
  scale_y_continuous(expand = c(0,0), limit = c(-1,17),
                     breaks = seq(-1, 17, by = 2)) +
  geom_hline(aes(yintercept=1), linetype=2)  +
  labs(x = "Flowers - Leaves", y = "Achromatic contrast (Delta-L)", 
       col = 'Light') +
  theme_bw() + 
  theme(axis.text.x = element_blank(), 
        axis.ticks = element_blank(),
        panel.grid.major.y = element_line(color="gray87"),
        panel.grid.minor.y = element_blank(),
        panel.grid.major.x = element_blank(),
        panel.grid.minor.x = element_blank(),
        legend.text = element_blank(),
        legend.position='none') 

### other backgrounds ----
# Gravel background
jnd.fh.fm.gravel_achro <- jnd.fh_achro(luz_lunallena, gravel, 'Full moon', 'b) Gravel background')
jnd.fh.st.gravel_achro <- jnd.fh_achro(luz_st1, gravel, 'Starlight', 'b) Gravel background')
jnd.fh.tw.gravel_achro <- jnd.fh_achro(luz_tw1, gravel, 'Twilight', 'b) Gravel background')
jnd.fh.hps.gravel_achro<- jnd.fh_achro(luz_hps, gravel, 'HPS', 'b) Gravel background')
jnd.fh.led.gravel_achro <- jnd.fh_achro(luz_led5000, gravel, 'LED', 'b) Gravel background')
jnd.fh.mv.gravel_achro <- jnd.fh_achro(luz_mv, gravel, 'MV', 'b) Gravel background')

jnd.fh.gravel_achro <- rbind(jnd.fh.fm.gravel_achro, jnd.fh.st.gravel_achro, 
                             jnd.fh.tw.gravel_achro, jnd.fh.led.gravel_achro,
                             jnd.fh.mv.gravel_achro, jnd.fh.hps.gravel_achro)
head(jnd.fh.gravel_achro)
jnd.fh.gravel_achro$luz <- factor(jnd.fh.gravel_achro$luz,
                            levels = c('Full moon', 'Twilight', 'Starlight',
                                       'LED', 'MV', 'HPS'))
jnd.fh.gravel_achro$parts <- rep('f-h', nrow(jnd.fh.gravel_achro))
jnd.fh.gravel_achro$cod <- rep(c(1, rep(2, 16)), 6)
jnd.fh.gravel_achro$col <- rep(c(NA, rep('b',12), rep('a', 4)), 6)
head(jnd.fh.gravel_achro)

# plot gravel background
ggplot(jnd.fh.gravel_achro) +
  geom_pointrange(aes(jnd.fh.gravel_achro[,8], #code to plot in two columns
                      jnd.fh.gravel_achro[,1], #dS.mean
                      ymin=jnd.fh.gravel_achro[,2], #dS.lwr
                      ymax=jnd.fh.gravel_achro[,3])) + #dS.upr 
  geom_point(aes(x = jnd.fh.gravel_achro[,8], #code to plot in two columns
                 y= jnd.fh.gravel_achro[,1], #dS.mean
                 col = jnd.fh.gravel_achro[,9])) + #col to indicate if it is yellow or white
  geom_text(aes(x = jnd.fh.gravel_achro[,8], #code to plot in two columns
                y= jnd.fh.gravel_achro[,1]), #dS.mean
            label = rep(c(0:16),6), 
            size = 2.7, hjust = 2) +
  facet_grid(cod~luz) +
  scale_y_continuous(expand = c(0,0), limit = c(-1,10.8), 
                     breaks = seq(-1, 10.8, by = 2)) +
  geom_hline(aes(yintercept=1), linetype=2)  +
  labs(x = "Flowers - Leaves", y = "Chromatic contrast (Delta-S)", 
       col = 'Light') +
  theme_bw() + 
  theme(axis.text.x = element_blank(), 
        axis.ticks = element_blank(),
        panel.grid.major.y = element_line(color="gray87"),
        panel.grid.minor.y = element_blank(),
        panel.grid.major.x = element_blank(),
        panel.grid.minor.x = element_blank(),
        legend.position='none')

# Sand background
jnd.fh.fm.sand_achro <- jnd.fh_achro(luz_lunallena, sand, 'Full moon', 'c) Sand background')
jnd.fh.st.sand_achro <- jnd.fh_achro(luz_st1, sand, 'Starlight', 'c) Sand background')
jnd.fh.tw.sand_achro <- jnd.fh_achro(luz_tw1, sand, 'Twilight', 'c) Sand background')
jnd.fh.hps.sand_achro <- jnd.fh_achro(luz_hps, sand, 'HPS', 'c) Sand background')
jnd.fh.led.sand_achro <- jnd.fh_achro(luz_led5000, sand, 'LED', 'c) Sand background')
jnd.fh.mv.sand_achro <- jnd.fh_achro(luz_mv, sand, 'MV', 'c) Sand background')

jnd.fh.sand_achro <- rbind(jnd.fh.fm.sand_achro, jnd.fh.st.sand_achro, 
                           jnd.fh.tw.sand_achro, jnd.fh.led.sand_achro,
                           jnd.fh.mv.sand_achro, jnd.fh.hps.sand_achro)
head(jnd.fh.sand_achro)
jnd.fh.sand_achro$luz <- factor(jnd.fh.sand_achro$luz,
                          levels = c('Full moon', 'Twilight', 'Starlight',
                                     'LED', 'MV', 'HPS'))
jnd.fh.sand_achro$parts <- rep('f-h', nrow(jnd.fh.sand_achro))
jnd.fh.sand_achro$cod <- rep(c(1, rep(2, 16)), 6)
jnd.fh.sand_achro$col <- rep(c(NA, rep('b',12), rep('a', 4)), 6)
head(jnd.fh.sand_achro)

# plot sand background
ggplot(jnd.fh.sand_achro) +
  geom_pointrange(aes(jnd.fh.sand_achro[,8], #code to plot in two columns
                      jnd.fh.sand_achro[,1], #dS.mean
                      ymin=jnd.fh.sand_achro[,2], #dS.lwr
                      ymax=jnd.fh.sand_achro[,3])) + #dS.upr 
  geom_point(aes(x = jnd.fh.sand_achro[,8], #code to plot in two columns
                 y= jnd.fh.sand_achro[,1], #dS.mean
                 col = jnd.fh.sand_achro[,9])) + #col to indicate if it is yellow or white
  geom_text(aes(x = jnd.fh.sand_achro[,8], #code to plot in two columns
                y= jnd.fh.sand_achro[,1]), #dS.mean
            label = rep(c(0:16),6), 
            size = 2.7, hjust = 2) +
  facet_grid(cod~luz) +
  scale_y_continuous(expand = c(0,0), limit = c(-1,10.8), 
                     breaks = seq(-1, 10.8, by = 2)) +
  geom_hline(aes(yintercept=1), linetype=2)  +
  labs(x = "Flowers - Leaves", y = "Chromatic contrast (Delta-S)", 
       col = 'Light') +
  theme_bw() + 
  theme(axis.text.x = element_blank(), 
        axis.ticks = element_blank(),
        panel.grid.major.y = element_line(color="gray87"),
        panel.grid.minor.y = element_blank(),
        panel.grid.major.x = element_blank(),
        panel.grid.minor.x = element_blank(),
        legend.position='none')

# Soil background
jnd.fh.fm.soil_achro <- jnd.fh_achro(luz_lunallena, soil, 'Full moon', 'd) Soil background')
jnd.fh.st.soil_achro <- jnd.fh_achro(luz_st1, soil, 'Starlight', 'd) Soil background')
jnd.fh.tw.soil_achro <- jnd.fh_achro(luz_tw1, soil, 'Twilight', 'd) Soil background')
jnd.fh.hps.soil_achro <- jnd.fh_achro(luz_hps, soil, 'HPS', 'd) Soil background')
jnd.fh.led.soil_achro <- jnd.fh_achro(luz_led5000, soil, 'LED', 'd) Soil background')
jnd.fh.mv.soil_achro <- jnd.fh_achro(luz_mv, soil, 'MV', 'd) Soil background')

jnd.fh.soil_achro <- rbind(jnd.fh.fm.soil_achro, jnd.fh.st.soil_achro, 
                           jnd.fh.tw.soil_achro, jnd.fh.led.soil_achro,
                           jnd.fh.mv.soil_achro, jnd.fh.hps.soil_achro)
head(jnd.fh.soil_achro)
jnd.fh.soil_achro$luz <- factor(jnd.fh.soil_achro$luz,
                          levels = c('Full moon', 'Twilight', 'Starlight',
                                     'LED', 'MV', 'HPS'))
jnd.fh.soil_achro$parts <- rep('f-h', nrow(jnd.fh.soil_achro))
jnd.fh.soil_achro$cod <- rep(c(1, rep(2, 16)), 6)
jnd.fh.soil_achro$col <- rep(c(NA, rep('b',12), rep('a', 4)), 6)
head(jnd.fh.soil_achro)

# plot soil background
ggplot(jnd.fh.soil_achro) +
  geom_pointrange(aes(jnd.fh.soil_achro[,8], #code to plot in two columns
                      jnd.fh.soil_achro[,1], #dS.mean
                      ymin=jnd.fh.soil_achro[,2], #dS.lwr
                      ymax=jnd.fh.soil_achro[,3])) + #dS.upr 
  geom_point(aes(x = jnd.fh.soil_achro[,8], #code to plot in two columns
                 y= jnd.fh.soil_achro[,1], #dS.mean
                 col = jnd.fh.soil_achro[,9])) + #col to indicate if it is yellow or white 
  geom_text(aes(x = jnd.fh.soil_achro[,8], #code to plot in two columns
                y= jnd.fh.soil_achro[,1]), #dS.mean
            label = rep(c(0:16),6), 
            size = 2.7, hjust = 2) +
  facet_grid(cod~luz) +
  scale_y_continuous(expand = c(0,0), limit = c(-1,10.8), 
                     breaks = seq(-1, 10.8, by = 2)) +
  geom_hline(aes(yintercept=1), linetype=2)  +
  labs(x = "Flowers - Leaves", y = "Chromatic contrast (Delta-S)", 
       col = 'Light') +
  theme_bw() + 
  theme(axis.text.x = element_blank(), 
        axis.ticks = element_blank(),
        panel.grid.major.y = element_line(color="gray87"),
        panel.grid.minor.y = element_blank(),
        panel.grid.major.x = element_blank(),
        panel.grid.minor.x = element_blank(),
        legend.position='none')  

# 6) PROCRUSTES ----
## a) Flowers' procrustes ----
head(flower_colors)

## Flowers' vismodel for each illumination and each background
jnd.f <- function (x,y) {
  vis <- vismodel(flower_colors, visual = m.sexta, qcatch = "Qi", achromatic = "l",
                  illum = x, relative = F, bkg = y, vonkries = T)
  colnames(vis) <- c("u", "s", "m","lum")
  vis
  cdist <- coldist(vis, n = c(0.1, 0.23, 0.67), noise='neural', 
                   weber = 0.1, weber.achro = 0.16, achro = F)  
  jnd <- jnd2xyz(cdist, ref1 = "m")
}

# Procrustes' test
proftest <- function (i,j){
  pro <- procrustes(i, j, symmetric = T)
  prof_test <- protest(i, j, scores="sites",scale=T,symmetric=T)
}

#### Flowers' procrustes green background ----
# for each illumination
jndf.fm.green <- jnd.f(luz_lunallena, green) 
jndf.tw.green <- jnd.f(luz_tw1, green) 
jndf.st.green <- jnd.f(luz_st1, green) 
jndf.led.green <- jnd.f(luz_led5000, green) 
jndf.mv.green <- jnd.f(luz_mv, green) 
jndf.hps.green <- jnd.f(luz_hps, green)

# for each pairwise comparison between illuminations
proftest_tw_st_green <- proftest(jndf.tw.green, jndf.st.green)
proftest_tw_hps_green <-proftest(jndf.tw.green, jndf.hps.green)
proftest_tw_led_green <- proftest(jndf.tw.green, jndf.led.green)
proftest_tw_mv_green <- proftest(jndf.tw.green, jndf.mv.green)
proftest_tw_fm_green <- proftest(jndf.tw.green, jndf.fm.green)
proftest_st_hps_green <- proftest(jndf.st.green, jndf.hps.green)
proftest_st_led_green <- proftest(jndf.st.green, jndf.led.green)
proftest_st_mv_green <- proftest(jndf.st.green, jndf.mv.green)
proftest_st_fm_green <- proftest(jndf.st.green, jndf.fm.green)
proftest_fm_hps_green <- proftest(jndf.fm.green, jndf.hps.green)
proftest_fm_led_green <- proftest(jndf.fm.green, jndf.led.green)
proftest_fm_mv_green <- proftest(jndf.fm.green, jndf.mv.green)

# Tile plot green background
# organize information to plot
lights2 <- c(rep('Full moon',5), rep('Twilight',4), rep('Starlight',3))
lights2 <- factor(lights2, levels = c('Full moon', 'Twilight', 'Starlight'))
lights3 <- c('HPS','MV','LED','Starlight','Twilight',
             'HPS','MV','LED','Starlight',
             'HPS','MV','LED')
lights3 <- factor(lights3, levels = c('LED','HPS','MV','Full moon','Starlight','Twilight'))
values <- c(proftest_fm_hps_green$scale, proftest_fm_mv_green$scale, proftest_fm_led_green$scale,
            proftest_st_fm_green$scale, proftest_tw_fm_green$scale, proftest_tw_hps_green$scale,
            proftest_tw_mv_green$scale, proftest_tw_led_green$scale, proftest_tw_st_green$scale, 
            proftest_st_hps_green$scale, proftest_st_mv_green$scale, proftest_st_led_green$scale)

tilef_green <- data.frame(lights2, lights3, values)
tilef_green

ggplot(tilef_green, aes(x = lights2, y = lights3, fill = values)) +
  geom_tile(color = "white",
            lwd = 1.5,
            linetype = 1) +
  coord_fixed() + 
  scale_fill_gradientn(limits= c(0.7,1), 
                       colors= viridis(15, option = 'mako', direction = -1)) +
  guides(fill = guide_colourbar(title = "Correlation")) +
  labs(x=NULL, y=NULL) +
  geom_text(aes(label = round(values,2)), color = "white", size = 3.5) +
  theme_classic()

# Plot procrustes' errors 
prof.fm.green <- function(i,j){
  pro <- procrustes(i, j, symmetric = T)
  residuals(pro)
  plot(pro, kind=2, type='text',  xlab = 'Species', main= NULL, 
       xaxt = 'n', yaxt = 'n', ylim = c(0,0.35), xlim = c(1,nrow(i)))
  axis(1, at = c(1:nrow(i)))
  axis(2, at = c(0, 0.1 , 0.2, 0.3, 0.4))
}

par(mfrow=c(1,3))
prof_fm_led_green <- prof.fm.green(jndf.fm.green, jndf.led.green)
title('A) Full moon vs. LED')
prof_fm_hps_green <- prof.fm.green(jndf.fm.green, jndf.hps.green)
title('B) Full moon vs. HPS')
prof_fm_mv_green <- prof.fm.green(jndf.fm.green, jndf.mv.green)
title('C) Full moon vs. MV')
layout(1)

#### other backgrounds ----
#### Flowers' procrustes gravel background
jndf.fm.gravel <- jnd.f(luz_lunallena, gravel) 
jndf.tw.gravel <- jnd.f(luz_tw1, gravel) 
jndf.st.gravel <- jnd.f(luz_st1, gravel) 
jndf.led.gravel <- jnd.f(luz_led5000, gravel) 
jndf.mv.gravel <- jnd.f(luz_mv, gravel) 
jndf.hps.gravel <- jnd.f(luz_hps, gravel)

proftest_tw_st_gravel <- proftest(jndf.tw.gravel, jndf.st.gravel)
proftest_tw_hps_gravel <-proftest(jndf.tw.gravel, jndf.hps.gravel)
proftest_tw_led_gravel <- proftest(jndf.tw.gravel, jndf.led.gravel)
proftest_tw_mv_gravel <- proftest(jndf.tw.gravel, jndf.mv.gravel)
proftest_tw_fm_gravel <- proftest(jndf.tw.gravel, jndf.fm.gravel)
proftest_st_hps_gravel <- proftest(jndf.st.gravel, jndf.hps.gravel)
proftest_st_led_gravel <- proftest(jndf.st.gravel, jndf.led.gravel)
proftest_st_mv_gravel <- proftest(jndf.st.gravel, jndf.mv.gravel)
proftest_st_fm_gravel <- proftest(jndf.st.gravel, jndf.fm.gravel)
proftest_fm_hps_gravel <- proftest(jndf.fm.gravel, jndf.hps.gravel)
proftest_fm_led_gravel <- proftest(jndf.fm.gravel, jndf.led.gravel)
proftest_fm_mv_gravel <- proftest(jndf.fm.gravel, jndf.mv.gravel)

# Plot procrustes' errors 
prof.fm.gravel <- function(i,j){
  pro <- procrustes(i, j, symmetric = T)
  residuals(pro)
  plot(pro, kind=2, type='text',  xlab = 'Species', main= NULL, 
       xaxt = 'n', yaxt = 'n', ylim = c(0,0.35), xlim = c(1,nrow(i)))
  axis(1, at = c(1:nrow(i)))
  axis(2, at = c(0, 0.1 , 0.2, 0.3, 0.4))
}

par(mfrow=c(1,3))
prof_fm_led_gravel <- prof.fm.gravel(jndf.fm.gravel, jndf.led.gravel)
title('A) Full moon vs. LED')
prof_fm_hps_gravel <- prof.fm.gravel(jndf.fm.gravel, jndf.hps.gravel)
title('B) Full moon vs. HPS')
prof_fm_mv_gravel <- prof.fm.gravel(jndf.fm.gravel, jndf.mv.gravel)
title('C) Full moon vs. MV')
layout(1)

# Tile plot gravel background
lights2 <- c(rep('Full moon',5), rep('Twilight',4), rep('Starlight',3))
lights2 <- factor(lights2, levels = c('Full moon', 'Twilight', 'Starlight'))
lights3 <- c('HPS','MV','LED','Starlight','Twilight',
             'HPS','MV','LED','Starlight',
             'HPS','MV','LED')
lights3 <- factor(lights3, levels = c('LED','HPS','MV','Full moon','Starlight','Twilight'))
values <- c(proftest_fm_hps_gravel$scale, proftest_fm_mv_gravel$scale, proftest_fm_led_gravel$scale,
            proftest_st_fm_gravel$scale, proftest_tw_fm_gravel$scale, proftest_tw_hps_gravel$scale,
            proftest_tw_mv_gravel$scale, proftest_tw_led_gravel$scale, proftest_tw_st_gravel$scale, 
            proftest_st_hps_gravel$scale, proftest_st_mv_gravel$scale, proftest_st_led_gravel$scale)

tilef_gravel <- data.frame(lights2, lights3, values)
tilef_gravel

ggplot(tilef_gravel, aes(x = lights2, y = lights3, fill = values)) +
  geom_tile(color = "white",
            lwd = 1.5,
            linetype = 1) +
  coord_fixed() + 
  scale_fill_gradientn(limits= c(0.7,1), 
                       colors= viridis(15, option = 'mako', direction = -1)) +
  guides(fill = guide_colourbar(title = "Correlation")) +
  labs(x=NULL, y=NULL) +
  geom_text(aes(label = round(values,2)), color = "white", size = 3.5) +
  theme_classic()

#### Flowers' procrustes sand background
jndf.fm.sand <- jnd.f(luz_lunallena, sand) 
jndf.tw.sand <- jnd.f(luz_tw1, sand) 
jndf.st.sand <- jnd.f(luz_st1, sand) 
jndf.led.sand <- jnd.f(luz_led5000, sand) 
jndf.mv.sand <- jnd.f(luz_mv, sand) 
jndf.hps.sand <- jnd.f(luz_hps, sand)

proftest_tw_st_sand <- proftest(jndf.tw.sand, jndf.st.sand)
proftest_tw_hps_sand <-proftest(jndf.tw.sand, jndf.hps.sand)
proftest_tw_led_sand <- proftest(jndf.tw.sand, jndf.led.sand)
proftest_tw_mv_sand <- proftest(jndf.tw.sand, jndf.mv.sand)
proftest_tw_fm_sand <- proftest(jndf.tw.sand, jndf.fm.sand)
proftest_st_hps_sand <- proftest(jndf.st.sand, jndf.hps.sand)
proftest_st_led_sand <- proftest(jndf.st.sand, jndf.led.sand)
proftest_st_mv_sand <- proftest(jndf.st.sand, jndf.mv.sand)
proftest_st_fm_sand <- proftest(jndf.st.sand, jndf.fm.sand)
proftest_fm_hps_sand <- proftest(jndf.fm.sand, jndf.hps.sand)
proftest_fm_led_sand <- proftest(jndf.fm.sand, jndf.led.sand)
proftest_fm_mv_sand <- proftest(jndf.fm.sand, jndf.mv.sand)

# Plot procrustes' errors 
prof.fm.sand <- function(i,j){
  pro <- procrustes(i, j, symmetric = T)
  residuals(pro)
  plot(pro, kind=2, type='text',  xlab = 'Species', main= NULL, 
       xaxt = 'n', yaxt = 'n', ylim = c(0,0.35), xlim = c(1,nrow(i)))
  axis(1, at = c(1:nrow(i)))
  axis(2, at = c(0, 0.1 , 0.2, 0.3, 0.4))
}

par(mfrow=c(1,3))
prof_fm_led_sand <- prof.fm.sand(jndf.fm.sand, jndf.led.sand)
title('A) Full moon vs. LED')
prof_fm_hps_sand <- prof.fm.sand(jndf.fm.sand, jndf.hps.sand)
title('B) Full moon vs. HPS')
prof_fm_mv_sand <- prof.fm.sand(jndf.fm.sand, jndf.mv.sand)
title('C) Full moon vs. MV')
layout(1)

# Tile plot sand background
lights2 <- c(rep('Full moon',5), rep('Twilight',4), rep('Starlight',3))
lights2 <- factor(lights2, levels = c('Full moon', 'Twilight', 'Starlight'))
lights3 <- c('HPS','MV','LED','Starlight','Twilight',
             'HPS','MV','LED','Starlight',
             'HPS','MV','LED')
lights3 <- factor(lights3, levels = c('LED','HPS','MV','Full moon','Starlight','Twilight'))
values <- c(proftest_fm_hps_sand$scale, proftest_fm_mv_sand$scale, proftest_fm_led_sand$scale,
            proftest_st_fm_sand$scale, proftest_tw_fm_sand$scale, proftest_tw_hps_sand$scale,
            proftest_tw_mv_sand$scale, proftest_tw_led_sand$scale, proftest_tw_st_sand$scale, 
            proftest_st_hps_sand$scale, proftest_st_mv_sand$scale, proftest_st_led_sand$scale)

tilef_sand <- data.frame(lights2, lights3, values)
tilef_sand

ggplot(tilef_sand, aes(x = lights2, y = lights3, fill = values)) +
  geom_tile(color = "white",
            lwd = 1.5,
            linetype = 1) +
  coord_fixed() + 
  scale_fill_gradientn(limits= c(0.7,1), 
                       colors= viridis(15, option = 'mako', direction = -1)) +
  guides(fill = guide_colourbar(title = "Correlation")) +
  labs(x=NULL, y=NULL) +
  geom_text(aes(label = round(values,2)), color = "white", size = 3.5) +
  theme_classic()

#### Flowers' procrustes soil background
jndf.fm.soil <- jnd.f(luz_lunallena, soil) 
jndf.tw.soil <- jnd.f(luz_tw1, soil) 
jndf.st.soil <- jnd.f(luz_st1, soil) 
jndf.led.soil <- jnd.f(luz_led5000, soil) 
jndf.mv.soil <- jnd.f(luz_mv, soil) 
jndf.hps.soil <- jnd.f(luz_hps, soil)

proftest_tw_st_soil <- proftest(jndf.tw.soil, jndf.st.soil)
proftest_tw_hps_soil <-proftest(jndf.tw.soil, jndf.hps.soil)
proftest_tw_led_soil <- proftest(jndf.tw.soil, jndf.led.soil)
proftest_tw_mv_soil <- proftest(jndf.tw.soil, jndf.mv.soil)
proftest_tw_fm_soil <- proftest(jndf.tw.soil, jndf.fm.soil)
proftest_st_hps_soil <- proftest(jndf.st.soil, jndf.hps.soil)
proftest_st_led_soil <- proftest(jndf.st.soil, jndf.led.soil)
proftest_st_mv_soil <- proftest(jndf.st.soil, jndf.mv.soil)
proftest_st_fm_soil <- proftest(jndf.st.soil, jndf.fm.soil)
proftest_fm_hps_soil <- proftest(jndf.fm.soil, jndf.hps.soil)
proftest_fm_led_soil <- proftest(jndf.fm.soil, jndf.led.soil)
proftest_fm_mv_soil <- proftest(jndf.fm.soil, jndf.mv.soil)

# Plot procrustes' errors 
prof.fm.soil <- function(i,j){
  pro <- procrustes(i, j, symmetric = T)
  residuals(pro)
  plot(pro, kind=2, type='text',  xlab = 'Species', main= NULL, 
       xaxt = 'n', yaxt = 'n', ylim = c(0,0.35), xlim = c(1,nrow(i)))
  axis(1, at = c(1:nrow(i)))
  axis(2, at = c(0, 0.1 , 0.2, 0.3, 0.4))
}

par(mfrow=c(1,3))
prof_fm_led_soil <- prof.fm.soil(jndf.fm.soil, jndf.led.soil)
title('A) Full moon vs. LED')
prof_fm_hps_soil <- prof.fm.soil(jndf.fm.soil, jndf.hps.soil)
title('B) Full moon vs. HPS')
prof_fm_mv_soil <- prof.fm.soil(jndf.fm.soil, jndf.mv.soil)
title('C) Full moon vs. MV')
layout(1)

# Tile plot soil background
lights2 <- c(rep('Full moon',5), rep('Twilight',4), rep('Starlight',3))
lights2 <- factor(lights2, levels = c('Full moon', 'Twilight', 'Starlight'))
lights3 <- c('HPS','MV','LED','Starlight','Twilight',
             'HPS','MV','LED','Starlight',
             'HPS','MV','LED')
lights3 <- factor(lights3, levels = c('LED','HPS','MV','Full moon','Starlight','Twilight'))
values <- c(proftest_fm_hps_soil$scale, proftest_fm_mv_soil$scale, proftest_fm_led_soil$scale,
            proftest_st_fm_soil$scale, proftest_tw_fm_soil$scale, proftest_tw_hps_soil$scale,
            proftest_tw_mv_soil$scale, proftest_tw_led_soil$scale, proftest_tw_st_soil$scale, 
            proftest_st_hps_soil$scale, proftest_st_mv_soil$scale, proftest_st_led_soil$scale)

tilef_soil <- data.frame(lights2, lights3, values)
tilef_soil

ggplot(tilef_soil, aes(x = lights2, y = lights3, fill = values)) +
  geom_tile(color = "white",
            lwd = 1.5,
            linetype = 1) +
  coord_fixed() + 
  scale_fill_gradientn(limits= c(0.7,1), 
                       colors= viridis(15, option = 'mako', direction = -1)) +
  guides(fill = guide_colourbar(title = "Correlation")) +
  labs(x=NULL, y=NULL) +
  geom_text(aes(label = round(values,2)), color = "white", size = 3.5) +
  theme_classic()

## b) Leaves' procrustes ----
head(leaves)

jnd.l <- function (x,y) {
  vis <- vismodel(leaves, visual = m.sexta, qcatch = "Qi", achromatic = "l",
                  illum = x, relative = F, bkg = y, vonkries = T)
  colnames(vis) <- c("u", "s", "m","lum")
  vis
  cdist <- coldist(vis, n = c(0.1, 0.23, 0.67), noise='neural', 
                   weber = 0.1, weber.achro = 0.16, achro = F) 
  jnd <- jnd2xyz(cdist, ref1 = "m")
  jnd
}

proltest <- function (i,j){
  pro <- procrustes(i, j, symmetric = T)
  prol_test <- protest(i, j, scores="sites",scale=T,symmetric=T)
}

#### Leaves' procrustes green background ----
jndl.fm.green <- jnd.l(luz_lunallena, green) 
jndl.tw.green <- jnd.l(luz_tw1, green) 
jndl.st.green <- jnd.l(luz_st1, green) 
jndl.led.green <- jnd.l(luz_led5000, green) 
jndl.mv.green <- jnd.l(luz_mv, green) 
jndl.hps.green <- jnd.l(luz_hps, green)

proltest_tw_st_green <- proltest(jndl.tw.green, jndl.st.green)
proltest_tw_hps_green <-proltest(jndl.tw.green, jndl.hps.green)
proltest_tw_led_green <- proltest(jndl.tw.green, jndl.led.green)
proltest_tw_mv_green <- proltest(jndl.tw.green, jndl.mv.green)
proltest_tw_fm_green <- proltest(jndl.tw.green, jndl.fm.green)
proltest_st_hps_green <- proltest(jndl.st.green, jndl.hps.green)
proltest_st_led_green <- proltest(jndl.st.green, jndl.led.green)
proltest_st_mv_green <- proltest(jndl.st.green, jndl.mv.green)
proltest_st_fm_green <- proltest(jndl.st.green, jndl.fm.green)
proltest_fm_hps_green <- proltest(jndl.fm.green, jndl.hps.green)
proltest_fm_led_green <- proltest(jndl.fm.green, jndl.led.green)
proltest_fm_mv_green <- proltest(jndl.fm.green, jndl.mv.green)

# Tile plot green background
lights2 <- c(rep('Full moon',5), rep('Twilight',4), rep('Starlight',3))
lights2 <- factor(lights2, levels = c('Full moon', 'Twilight', 'Starlight'))
lights3 <- c('HPS','MV','LED','Starlight','Twilight',
             'HPS','MV','LED','Starlight',
             'HPS','MV','LED')
lights3 <- factor(lights3, levels = c('LED','HPS','MV','Full moon','Starlight','Twilight'))
values <- c(proltest_fm_hps_green$scale, proltest_fm_mv_green$scale, proltest_fm_led_green$scale,
            proltest_st_fm_green$scale, proltest_tw_fm_green$scale, proltest_tw_hps_green$scale,
            proltest_tw_mv_green$scale, proltest_tw_led_green$scale, proltest_tw_st_green$scale, 
            proltest_st_hps_green$scale, proltest_st_mv_green$scale, proltest_st_led_green$scale)

tilel_green <- data.frame(lights2, lights3, values)
tilel_green

ggplot(tilel_green, aes(x = lights2, y = lights3, fill = values)) +
  geom_tile(color = "white",
            lwd = 1.5,
            linetype = 1) +
  geom_text(aes(label = round(values,2)), color = "white", size = 3.5) +
  coord_fixed() + 
  scale_fill_gradientn(limits= c(0.6,1), 
                       colors= viridis(15, option = 'mako', direction = -1)) +
  guides(fill = guide_colourbar(title = "Correlation")) +
  labs(x=NULL, y=NULL) +
  theme_classic()

# Plot procrustes' errors 
prol.fm.green <- function(i,j){
  pro <- procrustes(i, j, symmetric = T)
  plot(pro, kind=2, type='text',  xlab = 'Species', main= NULL, 
       xaxt = 'n', yaxt = 'n', ylim = c(0,0.6), xlim = c(1,nrow(i)))
  axis(1, at = c(1:nrow(i)))
  axis(2, at = c(0, 0.1 , 0.2, 0.3, 0.4, 0.5, 0.6, 0.6))
}

par(mfrow=c(1,3))
prol_fm_led_green <- prol.fm.green(jndl.fm.green, jndl.led.green)
title('A) Full moon vs. LED')
prol_fm_hps_green <- prol.fm.green(jndl.fm.green, jndl.hps.green)
title('B) Full moon vs. HPS')
prol_fm_mv_green <- prol.fm.green(jndl.fm.green, jndl.mv.green)
title('C) Full moon vs. MV')
layout(1)

#### other backgrounds ----
#### Leaves' procrustes gravel background
jndl.fm.gravel <- jnd.l(luz_lunallena, gravel) 
jndl.tw.gravel <- jnd.l(luz_tw1, gravel) 
jndl.st.gravel <- jnd.l(luz_st1, gravel) 
jndl.led.gravel <- jnd.l(luz_led5000, gravel) 
jndl.mv.gravel <- jnd.l(luz_mv, gravel) 
jndl.hps.gravel <- jnd.l(luz_hps, gravel)

proltest_tw_st_gravel <- proltest(jndl.tw.gravel, jndl.st.gravel)
proltest_tw_hps_gravel <-proltest(jndl.tw.gravel, jndl.hps.gravel)
proltest_tw_led_gravel <- proltest(jndl.tw.gravel, jndl.led.gravel)
proltest_tw_mv_gravel <- proltest(jndl.tw.gravel, jndl.mv.gravel)
proltest_tw_fm_gravel <- proltest(jndl.tw.gravel, jndl.fm.gravel)
proltest_st_hps_gravel <- proltest(jndl.st.gravel, jndl.hps.gravel)
proltest_st_led_gravel <- proltest(jndl.st.gravel, jndl.led.gravel)
proltest_st_mv_gravel <- proltest(jndl.st.gravel, jndl.mv.gravel)
proltest_st_fm_gravel <- proltest(jndl.st.gravel, jndl.fm.gravel)
proltest_fm_hps_gravel <- proltest(jndl.fm.gravel, jndl.hps.gravel)
proltest_fm_led_gravel <- proltest(jndl.fm.gravel, jndl.led.gravel)
proltest_fm_mv_gravel <- proltest(jndl.fm.gravel, jndl.mv.gravel)

# Plot procrustes' errors 
prol.fm.gravel <- function(i,j){
  pro <- procrustes(i, j, symmetric = T)
  plot(pro, kind=2, type='text',  xlab = 'Species', main= NULL, 
       xaxt = 'n', yaxt = 'n', ylim = c(0,0.6), xlim = c(1,nrow(i)))
  axis(1, at = c(1:nrow(i)))
  axis(2, at = c(0, 0.1 , 0.2, 0.3, 0.4, 0.5, 0.6, 0.6))
}

par(mfrow=c(1,3))
prol_fm_led_gravel <- prol.fm.gravel(jndl.fm.gravel, jndl.led.gravel)
title('A) Full moon vs. LED')
prol_fm_hps_gravel <- prol.fm.gravel(jndl.fm.gravel, jndl.hps.gravel)
title('B) Full moon vs. HPS')
prol_fm_mv_gravel <- prol.fm.gravel(jndl.fm.gravel, jndl.mv.gravel)
title('C) Full moon vs. MV')
layout(1)

# Tile plot gravel background 
lights2 <- c(rep('Full moon',5), rep('Twilight',4), rep('Starlight',3))
lights2 <- factor(lights2, levels = c('Full moon', 'Twilight', 'Starlight'))
lights3 <- c('HPS','MV','LED','Starlight','Twilight',
             'HPS','MV','LED','Starlight',
             'HPS','MV','LED')
lights3 <- factor(lights3, levels = c('LED','HPS','MV','Full moon','Starlight','Twilight'))
values <- c(proltest_fm_hps_gravel$scale, proltest_fm_mv_gravel$scale, proltest_fm_led_gravel$scale,
            proltest_st_fm_gravel$scale, proltest_tw_fm_gravel$scale, proltest_tw_hps_gravel$scale,
            proltest_tw_mv_gravel$scale, proltest_tw_led_gravel$scale, proltest_tw_st_gravel$scale, 
            proltest_st_hps_gravel$scale, proltest_st_mv_gravel$scale, proltest_st_led_gravel$scale)

tilel_gravel <- data.frame(lights2, lights3, values)
tilel_gravel

ggplot(tilel_gravel, aes(x = lights2, y = lights3, fill = values)) +
  geom_tile(color = "white",
            lwd = 1.5,
            linetype = 1) +
  geom_text(aes(label = round(values,2)), color = "white", size = 3.5) +
  coord_fixed() + 
  scale_fill_gradientn(limits= c(0.6,1), 
                       colors= viridis(15, option = 'mako', direction = -1)) +
  guides(fill = guide_colourbar(title = "Correlation")) +
  labs(x=NULL, y=NULL) +
  theme_classic()

#### Leaves' procrustes sand background
jndl.fm.sand <- jnd.l(luz_lunallena, sand) 
jndl.tw.sand <- jnd.l(luz_tw1, sand) 
jndl.st.sand <- jnd.l(luz_st1, sand) 
jndl.led.sand <- jnd.l(luz_led5000, sand) 
jndl.mv.sand <- jnd.l(luz_mv, sand) 
jndl.hps.sand <- jnd.l(luz_hps, sand)

proltest_tw_st_sand <- proltest(jndl.tw.sand, jndl.st.sand)
proltest_tw_hps_sand <-proltest(jndl.tw.sand, jndl.hps.sand)
proltest_tw_led_sand <- proltest(jndl.tw.sand, jndl.led.sand)
proltest_tw_mv_sand <- proltest(jndl.tw.sand, jndl.mv.sand)
proltest_tw_fm_sand <- proltest(jndl.tw.sand, jndl.fm.sand)
proltest_st_hps_sand <- proltest(jndl.st.sand, jndl.hps.sand)
proltest_st_led_sand <- proltest(jndl.st.sand, jndl.led.sand)
proltest_st_mv_sand <- proltest(jndl.st.sand, jndl.mv.sand)
proltest_st_fm_sand <- proltest(jndl.st.sand, jndl.fm.sand)
proltest_fm_hps_sand <- proltest(jndl.fm.sand, jndl.hps.sand)
proltest_fm_led_sand <- proltest(jndl.fm.sand, jndl.led.sand)
proltest_fm_mv_sand <- proltest(jndl.fm.sand, jndl.mv.sand)

# Plot procrustes' errors 
prol.fm.sand <- function(i,j){
  pro <- procrustes(i, j, symmetric = T)
  plot(pro, kind=2, type='text',  xlab = 'Species', main= NULL, 
       xaxt = 'n', yaxt = 'n', ylim = c(0,0.6), xlim = c(1,nrow(i)))
  axis(1, at = c(1:nrow(i)))
  axis(2, at = c(0, 0.1 , 0.2, 0.3, 0.4, 0.5, 0.6, 0.6))
}

par(mfrow=c(1,3))
prol_fm_led_sand <- prol.fm.sand(jndl.fm.sand, jndl.led.sand)
title('A) Full moon vs. LED')
prol_fm_hps_sand <- prol.fm.sand(jndl.fm.sand, jndl.hps.sand)
title('B) Full moon vs. HPS')
prol_fm_mv_sand <- prol.fm.sand(jndl.fm.sand, jndl.mv.sand)
title('C) Full moon vs. MV')
layout(1)

# Tile plot sand background
lights2 <- c(rep('Full moon',5), rep('Twilight',4), rep('Starlight',3))
lights2 <- factor(lights2, levels = c('Full moon', 'Twilight', 'Starlight'))
lights3 <- c('HPS','MV','LED','Starlight','Twilight',
             'HPS','MV','LED','Starlight',
             'HPS','MV','LED')
lights3 <- factor(lights3, levels = c('LED','HPS','MV','Full moon','Starlight','Twilight'))
values <- c(proltest_fm_hps_sand$scale, proltest_fm_mv_sand$scale, proltest_fm_led_sand$scale,
            proltest_st_fm_sand$scale, proltest_tw_fm_sand$scale, proltest_tw_hps_sand$scale,
            proltest_tw_mv_sand$scale, proltest_tw_led_sand$scale, proltest_tw_st_sand$scale, 
            proltest_st_hps_sand$scale, proltest_st_mv_sand$scale, proltest_st_led_sand$scale)

tilel_sand <- data.frame(lights2, lights3, values)
tilel_sand

ggplot(tilel_sand, aes(x = lights2, y = lights3, fill = values)) +
  geom_tile(color = "white",
            lwd = 1.5,
            linetype = 1) +
  geom_text(aes(label = round(values,2)), color = "white", size = 3.5) +
  coord_fixed() + 
  scale_fill_gradientn(limits= c(0.6,1), 
                       colors= viridis(15, option = 'mako', direction = -1)) +
  guides(fill = guide_colourbar(title = "Correlation")) +
  labs(x=NULL, y=NULL) +
  theme_classic()

#### Leaves' procrustes soil background
jndl.fm.soil <- jnd.l(luz_lunallena, soil) 
jndl.tw.soil <- jnd.l(luz_tw1, soil) 
jndl.st.soil <- jnd.l(luz_st1, soil) 
jndl.led.soil <- jnd.l(luz_led5000, soil) 
jndl.mv.soil <- jnd.l(luz_mv, soil) 
jndl.hps.soil <- jnd.l(luz_hps, soil)

proltest_tw_st_soil <- proltest(jndl.tw.soil, jndl.st.soil)
proltest_tw_hps_soil <-proltest(jndl.tw.soil, jndl.hps.soil)
proltest_tw_led_soil <- proltest(jndl.tw.soil, jndl.led.soil)
proltest_tw_mv_soil <- proltest(jndl.tw.soil, jndl.mv.soil)
proltest_tw_fm_soil <- proltest(jndl.tw.soil, jndl.fm.soil)
proltest_st_hps_soil <- proltest(jndl.st.soil, jndl.hps.soil)
proltest_st_led_soil <- proltest(jndl.st.soil, jndl.led.soil)
proltest_st_mv_soil <- proltest(jndl.st.soil, jndl.mv.soil)
proltest_st_fm_soil <- proltest(jndl.st.soil, jndl.fm.soil)
proltest_fm_hps_soil <- proltest(jndl.fm.soil, jndl.hps.soil)
proltest_fm_led_soil <- proltest(jndl.fm.soil, jndl.led.soil)
proltest_fm_mv_soil <- proltest(jndl.fm.soil, jndl.mv.soil)

# Plot procrustes' errors 
prol.fm.soil <- function(i,j){
  pro <- procrustes(i, j, symmetric = T)
  plot(pro, kind=2, type='text',  xlab = 'Species', main= NULL, 
       xaxt = 'n', yaxt = 'n', ylim = c(0,0.6), xlim = c(1,nrow(i)))
  axis(1, at = c(1:nrow(i)))
  axis(2, at = c(0, 0.1 , 0.2, 0.3, 0.4, 0.5, 0.6, 0.6))
}

par(mfrow=c(1,3))
prol_fm_led_soil <- prol.fm.soil(jndl.fm.soil, jndl.led.soil)
title('A) Full moon vs. LED')
prol_fm_hps_soil <- prol.fm.soil(jndl.fm.soil, jndl.hps.soil)
title('B) Full moon vs. HPS')
prol_fm_mv_soil <- prol.fm.soil(jndl.fm.soil, jndl.mv.soil)
title('C) Full moon vs. MV')
layout(1)

# Tile plot soil background
lights2 <- c(rep('Full moon',5), rep('Twilight',4), rep('Starlight',3))
lights2 <- factor(lights2, levels = c('Full moon', 'Twilight', 'Starlight'))
lights3 <- c('HPS','MV','LED','Starlight','Twilight',
             'HPS','MV','LED','Starlight',
             'HPS','MV','LED')
lights3 <- factor(lights3, levels = c('LED','HPS','MV','Full moon','Starlight','Twilight'))
values <- c(proltest_fm_hps_soil$scale, proltest_fm_mv_soil$scale, proltest_fm_led_soil$scale,
            proltest_st_fm_soil$scale, proltest_tw_fm_soil$scale, proltest_tw_hps_soil$scale,
            proltest_tw_mv_soil$scale, proltest_tw_led_soil$scale, proltest_tw_st_soil$scale, 
            proltest_st_hps_soil$scale, proltest_st_mv_soil$scale, proltest_st_led_soil$scale)

tilel_soil <- data.frame(lights2, lights3, values)
tilel_soil

ggplot(tilel_soil, aes(x = lights2, y = lights3, fill = values)) +
  geom_tile(color = "white",
            lwd = 1.5,
            linetype = 1) +
  geom_text(aes(label = round(values,2)), color = "white", size = 3.5) +
  coord_fixed() + 
  scale_fill_gradientn(limits= c(0.6,1), 
                       colors= viridis(15, option = 'mako', direction = -1)) +
  guides(fill = guide_colourbar(title = "Correlation")) +
  labs(x=NULL, y=NULL) +
  theme_classic()

